// ignore_for_file: non_constant_identifier_names, depend_on_referenced_packages

import 'package:calendar_date_picker2/calendar_date_picker2.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

import 'package:intl/intl.dart';

class AtilaUi extends StatelessWidget {
  const AtilaUi({super.key});

  @override
  Widget build(BuildContext context) {
    return Container();
  }

  /// Devuelve 'yyyy-MM-dd HH:mm:ss'
  static String fechas_GetCurrentDateTime() {
    final DateTime now = DateTime.now();
    final DateFormat formatter = DateFormat('yyyy-MM-dd HH:mm:ss');
    final String formatted = formatter.format(now);
    return formatted;
  }

  /// Devuelve 'dd/MM/yyyy HH:mm:ss'
  static String fechas_GetCurrentARGDateTime() {
    final DateTime now = DateTime.now();
    final DateFormat formatter = DateFormat('dd/MM/yyyy HH:mm:ss');
    final String formatted = formatter.format(now);
    return formatted;
  }

  /// Devuelve 'dd/MM/yyyy'
  static String fechas_GetCurrentARGDate() {
    final DateTime now = DateTime.now();
    final DateFormat formatter = DateFormat('dd/MM/yyyy');
    final String formatted = formatter.format(now);
    return formatted;
  }

  /// Convierte date a 'yyyy-MM-dd'
  static String fechas_ConvertDateToYYYYMMDD(DateTime date) {
    final DateFormat formatter = DateFormat('yyyy-MM-dd');
    final String formatted = formatter.format(date);
    return formatted;
  }

  /// Convierte 'dd/MM/yyyy' a 'yyyy-MM-dd'
  static String fechas_ConvertYYYYMMDDString(String date) {
    var inputFormat = DateFormat('dd/MM/yyyy');
    var date1 = inputFormat.parse(date);

    var outputFormat = DateFormat('yyyy-MM-dd');
    var formatted = outputFormat.format(date1);
    return formatted;
  }

  /// Convierte 'yyyy/mm/dd' a 'yyyy-MM-dd'
  static String fechas_ConvertirDDMMYYYYString(String date) {
    var inputFormat = DateFormat('yyyy/mm/dd');
    var date1 = inputFormat.parse(date);

    var outputFormat = DateFormat('yyyy-MM-dd');
    var formatted = outputFormat.format(date1);
    return formatted;
  }

  /// Convierte date a 'dd/MM/yyyy'
  static String fechas_ConvertirDDMMYYYY(DateTime date) {
    final DateFormat formatter = DateFormat('dd/MM/yyyy');
    final String formatted = formatter.format(date);
    return formatted;
  }

  /// Devuelve 'yyyy-MM-dd HH:mm:ss'
  static String fechas_SingleDateToString(
    CalendarDatePicker2Type datePickerType,
    List<DateTime?> values,
  ) {
    var valueText = (values.isNotEmpty ? values[0] : null)
        .toString()
        .replaceAll('00:00:00.000', '');

    if (datePickerType == CalendarDatePicker2Type.single) {
      if (values.isNotEmpty) {
        if (values.length == 1) {
          values.add(values[0]);
        }

        String startDate =
            '${values[0]!.day.toString().padLeft(2, '0')}/${values[0]!.month.toString().padLeft(2, '0')}/${values[0]!.year}';

        valueText = startDate;
      } else {
        return 'null';
      }
    }

    return valueText;
  }

  /// Convierte CalendarDatePicker2Type a  'dd/mm/yyyy'
  static String fechas_RangeDateToString(
    CalendarDatePicker2Type datePickerType,
    List<DateTime?> values,
  ) {
    var valueText = (values.isNotEmpty ? values[0] : null)
        .toString()
        .replaceAll('00:00:00.000', '');

    if (datePickerType == CalendarDatePicker2Type.range) {
      if (values.isNotEmpty) {
        if (values.length == 1) {
          values.add(values[0]);
        }

        String startDate =
            '${values[0]!.day.toString().padLeft(2, '0')}/${values[0]!.month.toString().padLeft(2, '0')}/${values[0]!.year}';
        String endDate = values[1] != null
            ? '${values[1]!.day.toString().padLeft(2, '0')}/${values[1]!.month.toString().padLeft(2, '0')}/${values[1]!.year}'
            : 'null';

        valueText = '$startDate - $endDate';
      } else {
        return 'null';
      }
    }

    return valueText;
  }

  /// Convierte CalendarDatePicker2Type a  'dd/mm/yyyy - dd/mm/yyyy'
  static String fechas_RangeDateToStringYYYYMMDD(
    CalendarDatePicker2Type datePickerType,
    List<DateTime?> values,
  ) {
    var valueText = (values.isNotEmpty ? values[0] : null)
        .toString()
        .replaceAll('00:00:00.000', '');

    if (datePickerType == CalendarDatePicker2Type.range) {
      if (values.isNotEmpty) {
        if (values.length == 1) {
          values.add(values[0]);
        }

        String startDate =
            '${values[0]!.year}-${values[0]!.month.toString().padLeft(2, '0')}-${values[0]!.day.toString().padLeft(2, '0')}';
        String endDate = values[1] != null
            ? '${values[1]!.year}-${values[1]!.month.toString().padLeft(2, '0')}-${values[1]!.day.toString().padLeft(2, '0')}'
            : 'null';

        valueText = '$startDate - $endDate';
      } else {
        return 'null';
      }
    }

    return valueText;
  }

  /// Abre calendario y devuelve List<DateTime?>
  static Future<List<DateTime?>?> fechas_BuildCalendar(
      {required BuildContext context,
      required List<DateTime?> initialValue}) async {
    var results = await showCalendarDatePicker2Dialog(
      context: context,
      config: CalendarDatePicker2WithActionButtonsConfig(
        cancelButton: TextButton(
          onPressed: () {
            Navigator.pop(context);
          },
          child: const Text(
            'CANCELAR',
            style: TextStyle(color: Colors.black54),
          ),
        ),
        okButtonTextStyle:
            const TextStyle(color: Colors.black, fontWeight: FontWeight.bold),
        calendarType: CalendarDatePicker2Type.single,
        selectedDayHighlightColor: Theme.of(context).primaryColor,
        weekdayLabelTextStyle: const TextStyle(
          color: Colors.black87,
          fontWeight: FontWeight.bold,
        ),
        controlsTextStyle: const TextStyle(
          color: Colors.black,
          fontSize: 15,
          fontWeight: FontWeight.bold,
        ),
      ),
      dialogSize: const Size(325, 430),
      initialValue: initialValue,
    );

    return results;
  }

  /// Abre calendario y devuelve List<DateTime?>
  static Future<List<DateTime?>?> fechas_BuildCalendarRange(
      {required BuildContext context,
      required List<DateTime?> initialValue}) async {
    var results = await showCalendarDatePicker2Dialog(
      context: context,
      config: CalendarDatePicker2WithActionButtonsConfig(
        cancelButton: TextButton(
          onPressed: () {
            Navigator.pop(context);
          },
          child:
              const Text('CANCELAR', style: TextStyle(color: Colors.black54)),
        ),
        okButtonTextStyle:
            const TextStyle(color: Colors.black, fontWeight: FontWeight.bold),
        calendarType: CalendarDatePicker2Type.range,
        selectedDayHighlightColor: Theme.of(context).primaryColor,
        weekdayLabelTextStyle: const TextStyle(
          color: Colors.black87,
          fontWeight: FontWeight.bold,
        ),
        controlsTextStyle: const TextStyle(
          color: Colors.black,
          fontSize: 15,
          fontWeight: FontWeight.bold,
        ),
      ),
      dialogSize: const Size(325, 430),
      initialValue: initialValue,
    );

    return results;
  }

  static String utils_GetCurrentDateTime() {
    final DateTime now = DateTime.now();
    final DateFormat formatter = DateFormat('yyyyMMddHHmmss');
    final String formatted = formatter.format(now);
    return formatted;
  }

  static const anchoPantallMobile = 900;
  static const anchoPantallTablet = 700;

  static bool device_esWebCli() {
    if (defaultTargetPlatform == TargetPlatform.iOS ||
        defaultTargetPlatform == TargetPlatform.android) {
      return false;
    } else if (defaultTargetPlatform == TargetPlatform.linux ||
        defaultTargetPlatform == TargetPlatform.macOS ||
        defaultTargetPlatform == TargetPlatform.windows) {
      return false;
    }
    return true;
  }

  static bool device_esAndroid() {
    return (defaultTargetPlatform == TargetPlatform.android);
  }

  static bool device_usaTacking() {
    return (defaultTargetPlatform == TargetPlatform.iOS ||
        defaultTargetPlatform == TargetPlatform.android);
  }

  static bool device_esMobile(double width) {
    return width < anchoPantallMobile;
  }

  static void alerts_simple(
      BuildContext context, String title, String message) {
    Widget cancelButton = TextButton(
      child: Text('OK',
          style: TextStyle(
              fontWeight: FontWeight.w400,
              color: Theme.of(context).primaryColor)),
      onPressed: () {
        Navigator.pop(context);
      },
    );

    AlertDialog alert = AlertDialog(
      title: Text(title),
      content: Text(message),
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadius.all(
          Radius.circular(20),
        ),
      ),
      actions: [
        cancelButton,
      ],
    );

    showDialog(
      context: context,
      builder: (BuildContext context) {
        return alert;
      },
    );
  }

  static void alerts_simpleConRedireccion(BuildContext context, String title,
      String message, String acceptText, Function acceptFunction) {
    Widget acceptButton = TextButton(
      child: Text(
        acceptText,
        style: TextStyle(
            fontWeight: FontWeight.w600, color: Theme.of(context).primaryColor),
      ),
      onPressed: () => acceptFunction(),
    );

    AlertDialog alert = AlertDialog(
      title: Text(title),
      content: Text(message),
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadius.all(
          Radius.circular(20),
        ),
      ),
      actions: [
        acceptButton,
      ],
    );

    showDialog(
      context: context,
      builder: (BuildContext context) {
        return alert;
      },
    );
  }

  static void alerts_loadingSpinner(BuildContext context, String label) {
    showDialog(
      context: context,
      barrierDismissible: false,
      builder: (BuildContext context) {
        return Dialog(
          elevation: 10,
          shape: const RoundedRectangleBorder(
            borderRadius: BorderRadius.all(
              Radius.circular(20.0),
            ),
          ),
          child: Container(
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(20),
              color: Colors.white,
            ),
            padding: const EdgeInsets.symmetric(horizontal: 30, vertical: 40),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                CircularProgressIndicator(
                  strokeWidth: 8,
                  valueColor: AlwaysStoppedAnimation<Color>(
                    Theme.of(context).primaryColor,
                  ),
                ),
                const SizedBox(height: 20),
                Text(
                  label,
                  textAlign: TextAlign.center,
                  style: const TextStyle(
                      fontSize: 14, fontWeight: FontWeight.w400),
                ),
              ],
            ),
          ),
        );
      },
    );
  }

  static void alerts_snackBar(BuildContext context, String message) {
    ScaffoldMessenger.of(context).showSnackBar(
      SnackBar(
        backgroundColor: Colors.grey[800],
        elevation: 20.0,
        margin: const EdgeInsets.symmetric(horizontal: 20, vertical: 50),
        padding: const EdgeInsets.only(left: 10, bottom: 10, top: 10),
        shape: const RoundedRectangleBorder(
          borderRadius: BorderRadius.all(Radius.circular(10)),
        ),
        action: SnackBarAction(
          label: 'OK',
          textColor: Colors.white,
          onPressed: () {},
        ),
        behavior: SnackBarBehavior.floating,
        duration: const Duration(seconds: 4),
        content: Text(
          message,
          style: const TextStyle(
            fontWeight: FontWeight.w500,
            fontSize: 14.0,
            color: Colors.white,
          ),
        ),
      ),
    );
  }

  static void alerts_snackBarError(BuildContext context, String message) {
    ScaffoldMessenger.of(context).showSnackBar(
      SnackBar(
        backgroundColor: Colors.red[900],
        elevation: 20.0,
        margin: const EdgeInsets.symmetric(horizontal: 20, vertical: 50),
        padding: const EdgeInsets.only(left: 10, bottom: 10, top: 10),
        shape: const RoundedRectangleBorder(
          borderRadius: BorderRadius.all(
            Radius.circular(10),
          ),
        ),
        action: SnackBarAction(
          label: 'OK',
          textColor: Colors.white, // or some operation you would like
          onPressed: () {
            // this block runs when label is pressed
          },
        ),
        behavior: SnackBarBehavior.floating,
        duration: const Duration(seconds: 4),
        content: Text(
          message,
          style: const TextStyle(
            fontWeight: FontWeight.w500,
            fontSize: 14.0,
            color: Colors.white,
          ),
        ),
      ),
    );
  }

  static void alerts_confirmar(BuildContext context, String title,
      String message, String acceptText, Function acceptFunction) {
    Widget cancelButton = TextButton(
      child: const Text(
        'CERRAR',
        style: TextStyle(
          fontWeight: FontWeight.w400,
          color: Colors.grey,
        ),
      ),
      onPressed: () {
        Navigator.pop(context);
      },
    );

    Widget acceptButton = TextButton(
      child: Text(
        acceptText,
        style: TextStyle(
            fontWeight: FontWeight.w600, color: Theme.of(context).primaryColor),
      ),
      onPressed: () => acceptFunction(),
    );

    AlertDialog alert = AlertDialog(
      title: Text(title),
      content: Text(message),
      shape: const RoundedRectangleBorder(
        borderRadius: BorderRadius.all(
          Radius.circular(20),
        ),
      ),
      actions: [cancelButton, acceptButton],
    );

    showDialog(
      context: context,
      builder: (BuildContext context) {
        return alert;
      },
    );
  }
}
